# Ape-Docs

```{eval-rst}
.. toctree::
   :caption: User Guides
   :maxdepth: 1

   userguides/quickstart
   userguides/accounts
   userguides/installing_plugins
   userguides/projects
   userguides/dependencies
   userguides/compile
   userguides/clis
   userguides/data
   userguides/networks
   userguides/developing_plugins
   userguides/config
   userguides/transactions
   userguides/console
   userguides/contracts
   userguides/proxy
   userguides/testing
   userguides/scripts
   userguides/publishing
```

```{eval-rst}
.. toctree::
   :caption: CLI Reference
   :maxdepth: 1

   commands/accounts.rst
   commands/compile.rst
   commands/pm.rst
   commands/console.rst
   commands/init.rst
   commands/networks.rst
   commands/plugins.rst
   commands/run.rst
   commands/test.rst
```

```{eval-rst}
.. toctree::
   :caption: Python Reference
   :maxdepth: 1

   methoddocs/ape.md
   methoddocs/api.md
   methoddocs/cli.md
   methoddocs/contracts.md
   methoddocs/exceptions.md
   methoddocs/managers.md
   methoddocs/plugins.md
   methoddocs/types.md
   methoddocs/utils.md
```
